﻿using System;
using System.Configuration;
using System.Data;
using System.Data.SqlClient;

/// <summary>
/// 설  명 : 현재 웹 사이트에서 사용되는 모든 Database처리 로직
/// 작성자 : 박용준
/// 작성일 : 
/// 변경일 : 
/// 기타 : 
/// 등등 : 
/// </summary>
public class UploadDac
{
    #region 필드
    private string _ConnectionString; // 연결문자열보관
    #endregion

    #region 생성자
    public UploadDac()
    {
        // Web.config의 <connectionStrings> 섹션의 값 읽어서 보관
        _ConnectionString =
            ConfigurationManager.ConnectionStrings[
                "ConnectionString"].ConnectionString;
    } 
    #endregion

    #region 메서드

    #region 입력 : AddUpload()
    /// <summary>
    /// 자료실에 데이터를 입력하는 메서드
    /// </summary>
    /// <param name="name"></param>
    /// <param name="email"></param>
    /// <param name="title"></param>
    /// <param name="postIp"></param>
    /// <param name="content"></param>
    /// <param name="password"></param>
    /// <param name="encoding"></param>
    /// <param name="homepage"></param>
    /// <param name="fileName"></param>
    /// <param name="fileSize"></param>
    /// <returns>입력된 레코드 수 반환</returns>
    public int AddUpload(
        string name, string email, string title, string postIp, string content
        , string password, string encoding, string homepage, string fileName, int fileSize)
    {
        SqlConnection con = new SqlConnection(_ConnectionString);

        SqlCommand cmd = new SqlCommand("WriteUpload", con);
        cmd.CommandType = CommandType.StoredProcedure;

        cmd.Parameters.AddWithValue("@Name", name);
        cmd.Parameters.AddWithValue("@Email", email);
        cmd.Parameters.AddWithValue("@Title", title);
        cmd.Parameters.AddWithValue("@PostIp", postIp);
        cmd.Parameters.AddWithValue("@Content", content);
        cmd.Parameters.AddWithValue("@Password", password);
        cmd.Parameters.AddWithValue("@Encoding", encoding);
        cmd.Parameters.AddWithValue("@Homepage", homepage);
        cmd.Parameters.AddWithValue("@FileName", fileName);
        cmd.Parameters.AddWithValue("@FileSize", fileSize);

        con.Open();
        int result = cmd.ExecuteNonQuery();
        con.Close();

        return result;
    }
    #endregion

    #region 출력 : GetUploads()
    /// <summary>
    /// 출력 : 자료실 리스트
    /// </summary>
    /// <returns>데이터셋</returns>
    public DataSet GetUploads()
    {
        SqlConnection conn = new SqlConnection(_ConnectionString);

        SqlCommand cmd = new SqlCommand("ListUpload", conn);
        cmd.CommandType = CommandType.StoredProcedure;

        SqlDataAdapter da = new SqlDataAdapter(cmd);

        DataSet ds = new DataSet();

        da.Fill(ds, "Upload");

        return ds;
    }
    #endregion

    /// <summary>
    /// 상세 : 자료실 콘텐츠 보기
    /// </summary>
    /// <param name="num"></param>
    public SqlDataReader GetUploadByNum(int num)
    {
        SqlConnection conn = new SqlConnection(_ConnectionString);
        conn.Open(); //  

        SqlCommand cmd = new SqlCommand("ViewUpload", conn);
        cmd.CommandType = CommandType.StoredProcedure;

        cmd.Parameters.AddWithValue("@Num", num);

        SqlDataReader dr = cmd.ExecuteReader();

        return dr; // Close() -> uisng () {} 사용해서 Close() 처리 필요
    }
    /// <summary>
    /// 수정 : 자료실 수정
    /// </summary>
    /// <param name="entity"></param>
    /// <returns></returns>
    public int UpdateUpload(UploadEntity entity)
    {
        SqlConnection con = new SqlConnection(_ConnectionString);

        SqlCommand cmd = new SqlCommand("ModifyUpload", con);
        cmd.CommandType = CommandType.StoredProcedure;

        cmd.Parameters.AddWithValue("@Name", entity.Name);
        cmd.Parameters.AddWithValue("@Email", entity.Email);
        cmd.Parameters.AddWithValue("@Title", entity.Title);
        cmd.Parameters.AddWithValue("@ModifyIp", entity.ModifyIP);
        cmd.Parameters.AddWithValue("@Content", entity.Content);
        cmd.Parameters.AddWithValue("@Encoding", entity.Encoding);
        cmd.Parameters.AddWithValue("@Homepage", entity.Homepage);
        cmd.Parameters.AddWithValue("@Password", entity.Password);
        cmd.Parameters.AddWithValue("@FileName", entity.FileName);
        cmd.Parameters.AddWithValue("@FileSize", entity.FileSize);
        cmd.Parameters.AddWithValue("@Num", entity.Num);

        con.Open();
        int result = cmd.ExecuteNonQuery();
        con.Close();

        return result;
    }
    /// <summary>
    /// 삭제
    /// </summary>
    /// <param name="num"></param>
    /// <param name="password"></param>
    /// <returns></returns>
    public int DeleteUpload(int num, string password)
    {
        SqlConnection con = new SqlConnection(_ConnectionString);
        SqlCommand cmd = new SqlCommand("DeleteUpload", con);
        cmd.CommandType = CommandType.StoredProcedure;
        cmd.Parameters.AddWithValue("@Password", password);
        cmd.Parameters.AddWithValue("@Num", num);
        con.Open();
        int result = cmd.ExecuteNonQuery();
        con.Close();
        return result;
    }

    /// <summary>
    /// 검색
    /// </summary>
    /// <param name="searchField"></param>
    /// <param name="searchQuery"></param>
    /// <returns></returns>
    public IDataReader GetUploadsByWord(string searchField, string searchQuery)
    {
        SqlConnection conn = new SqlConnection(_ConnectionString);

        SqlCommand cmd = new SqlCommand("SearchUpload", conn);
        cmd.CommandType = CommandType.StoredProcedure;

        cmd.Parameters.AddWithValue("@SearchField", searchField);
        cmd.Parameters.AddWithValue("@SearchQuery", searchQuery);

        conn.Open(); // ***
        SqlDataReader dr = cmd.ExecuteReader();

        return dr; // Close() -> uisng () {} 사용해서 Close() 처리 필요
    }

    /// <summary>
    /// 다운
    /// </summary>
    /// <param name="num"></param>
    public void UpdateDownCount(string fileName)
    {
        SqlConnection con = new SqlConnection(_ConnectionString);
        SqlCommand cmd = new SqlCommand("IncreaseDownCountUpload", con);
        cmd.CommandType = CommandType.StoredProcedure;
        cmd.Parameters.AddWithValue("@FileName", fileName);
        con.Open();
        cmd.ExecuteNonQuery();
        con.Close();
    } 
    #endregion
}
